@@ -1,3 +1,4 @@
+from abc import ABC
 from pathlib import Path
 from typing import List, Union
 
@@ -5,8 +6,17 @@ from sc2.bot_ai import BotAI
 from sc2.data import AIBuild, Difficulty, PlayerType, Race
 
 
-class AbstractPlayer:
-    def __init__(self, p_type, race=None, name=None, difficulty=None, ai_build=None, fullscreen=False):
+class AbstractPlayer(ABC):
+
+    def __init__(
+        self,
+        p_type: PlayerType,
+        race: Race = None,
+        name: str = None,
+        difficulty=None,
+        ai_build=None,
+        fullscreen=False
+    ):
         assert isinstance(p_type, PlayerType), f"p_type is of type {type(p_type)}"
         assert name is None or isinstance(name, str), f"name is of type {type(name)}"
 
@@ -39,17 +49,18 @@ class AbstractPlayer:
 
 
 class Human(AbstractPlayer):
+
     def __init__(self, race, name=None, fullscreen=False):
         super().__init__(PlayerType.Participant, race, name=name, fullscreen=fullscreen)
 
     def __str__(self):
         if self.name is not None:
             return f"Human({self.race._name_}, name={self.name !r})"
-        else:
-            return f"Human({self.race._name_})"
+        return f"Human({self.race._name_})"
 
 
 class Bot(AbstractPlayer):
+
     def __init__(self, race, ai, name=None, fullscreen=False):
         """
         AI can be None if this player object is just used to inform the
@@ -62,11 +73,11 @@ class Bot(AbstractPlayer):
     def __str__(self):
         if self.name is not None:
             return f"Bot {self.ai.__class__.__name__}({self.race._name_}), name={self.name !r})"
-        else:
-            return f"Bot {self.ai.__class__.__name__}({self.race._name_})"
+        return f"Bot {self.ai.__class__.__name__}({self.race._name_})"
 
 
 class Computer(AbstractPlayer):
+
     def __init__(self, race, difficulty=Difficulty.Easy, ai_build=AIBuild.RandomBuild):
         super().__init__(PlayerType.Computer, race, difficulty=difficulty, ai_build=ai_build)
 
@@ -75,6 +86,7 @@ class Computer(AbstractPlayer):
 
 
 class Observer(AbstractPlayer):
+
     def __init__(self):
         super().__init__(PlayerType.Observer)
 
@@ -83,6 +95,12 @@ class Observer(AbstractPlayer):
 
 
 class Player(AbstractPlayer):
+
+    def __init__(self, player_id, p_type, requested_race, difficulty=None, actual_race=None, name=None, ai_build=None):
+        super().__init__(p_type, requested_race, difficulty=difficulty, name=name, ai_build=ai_build)
+        self.id: int = player_id
+        self.actual_race: Race = actual_race
+
     @classmethod
     def from_proto(cls, proto):
         if PlayerType(proto.type) == PlayerType.Observer:
@@ -96,11 +114,6 @@ class Player(AbstractPlayer):
             proto.player_name if proto.HasField("player_name") else None,
         )
 
-    def __init__(self, player_id, p_type, requested_race, difficulty=None, actual_race=None, name=None, ai_build=None):
-        super().__init__(p_type, requested_race, difficulty=difficulty, name=name, ai_build=ai_build)
-        self.id: int = player_id
-        self.actual_race: Race = actual_race
-
 
 class BotProcess(AbstractPlayer):
     """
@@ -120,6 +133,7 @@ class BotProcess(AbstractPlayer):
     e.g. to call a bot capable of running on the bot ladders:
         BotProcess(os.getcwd(), "python run.py", Race.Terran, "INnoVation")
     """
+
     def __init__(
         self,
         path: Union[str, Path],
@@ -133,10 +147,7 @@ class BotProcess(AbstractPlayer):
         other_args: str = None,
         stdout: str = None,
     ):
-        self.race = race
-        self.type = PlayerType.Participant
-        self.name = name
-
+        super().__init__(PlayerType.Participant, race, name=name)
         assert Path(path).exists()
         self.path = path
         self.launch_list = launch_list
